AbstractHeapType

Enum AbstractHeapType 

pub enum AbstractHeapType {
Show 14 variants Func, Extern, Exn, Cont, Any, Eq, Struct, Array, I31, NoFunc, NoExtern, None, NoExn, NoCont,
}
An abstract heap type.

Variants



Func

An untyped function reference: funcref. This is part of the reference types proposal.



Extern

A reference to any host value: externref. This is part of the reference types proposal.



Exn

A reference to a wasm exception. This is part of the exceptions proposal.



Cont

A reference to a wasm continuation. This is part of the stack switching proposal.



Any

A reference to any reference value: anyref. This is part of the GC proposal.



Eq

A reference that has an identity that can be compared: eqref. This is part of the GC proposal.



Struct

A reference to a GC struct. This is part of the GC proposal.



Array

A reference to a GC array. This is part of the GC proposal.



I31

An unboxed 31-bit integer: i31ref. Part of the GC proposal.



NoFunc

The bottom type of the funcref hierarchy. Part of the GC proposal.



NoExtern

The bottom type of the externref hierarchy. Part of the GC proposal.



None

The bottom type of the anyref hierarchy. Part of the GC proposal.



NoExn

The bottom type of the exnref hierarchy. Part of the exceptions proposal.



NoCont

The bottom type of the contref hierarchy. Part of the stack switching proposal.