pub enum ImportItems<'a> {
Single {
module: &'a str,
name: &'a str,
sig: ItemSig<'a>,
},
Group1 {
module: &'a str,
items: Vec<ImportGroup1Item<'a>>,
},
Group2 {
module: &'a str,
sig: ItemSig<'a>,
items: Vec<ImportGroup2Item<'a>>,
},
}Expand description
The individual items inside an import statement, possibly in one of the
“compact” forms.
Variants
Single
A single import item:
(import "mod" "name" <type>)Fields
Group1
A group of import items with a common module name:
(import "mod" (item "foo" <type>) (item "bar" <type>))Fields

items: Vec<ImportGroup1Item<'a>>The individual items being imported (name/type).
Group2
A group of import items with a common module name and type:
(import "mod" (item "foo") (item "bar") <type>)Trait Implementations
Sourceimpl<'a> Clone for ImportItems<'a>
impl<'a> Clone for ImportItems<'a>
Sourcefn clone(&self) -> ImportItems<'a>
fn clone(&self) -> ImportItems<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<'a> Freeze for ImportItems<'a>
impl<'a> RefUnwindSafe for ImportItems<'a>
impl<'a> Send for ImportItems<'a>
impl<'a> Sync for ImportItems<'a>
impl<'a> Unpin for ImportItems<'a>
impl<'a> UnsafeUnpin for ImportItems<'a>
impl<'a> UnwindSafe for ImportItems<'a>