[−][src]Enum wast::InstanceKind
Possible ways to define a instance in the text format.
Variants
An instance which is actually defined as an import, such as:
Fields of Import
import: InlineImport<'a>Where we're importing from
ty: TypeUse<'a, InstanceType<'a>>The type that this instance will have.
Instances whose instantiation is defined inline.
Fields of Inline
module: Index<'a>Module that we're instantiating
items: Vec<ExportKind<'a>>Items used to instantiate the instance