pub enum CanonOpt<'a> {
StringUtf8,
StringUtf16,
StringLatin1Utf16,
Memory(CoreItemRef<'a, memory>),
Realloc(CoreItemRef<'a, func>),
PostReturn(CoreItemRef<'a, func>),
Async,
Callback(CoreItemRef<'a, func>),
CoreType(CoreItemRef<'a, type>),
Gc,
}Available on crate feature
component-model only.Expand description
Canonical ABI options.
Variants
StringUtf8
Encode strings as UTF-8.
StringUtf16
Encode strings as UTF-16.
StringLatin1Utf16
Encode strings as “compact UTF-16”.
Memory(CoreItemRef<'a, memory>)
Use the specified memory for canonical ABI memory access.
Realloc(CoreItemRef<'a, func>)
Use the specified reallocation function for memory allocations.
PostReturn(CoreItemRef<'a, func>)
Call the specified function after the lifted function has returned.
Async
Use the async ABI for lifting or lowering.
Callback(CoreItemRef<'a, func>)
Use the specified function to deliver async events to stackless coroutines.
CoreType(CoreItemRef<'a, type>)
Lower this component function into the specified core function type.
Gc
Use the GC variant of the canonical ABI.